//-------------------------------------------------------------------------------------
// Menu Item Import Script
//
// Purpose: Prepare Micros 3700 Menu Item Names and Prices in Excel. 
//
// Input file format:
// 
// Number,Mi_Seq,Name 1,Name 2,SLU,Mi_Slu_Seq,Price 1,Price 2,Price 3,Price 4,Price 5,
// Price 6,Price 7,Price 8,Price 9,Price 10
//
// Values in SLU,Mi_Slu_Seq fields are currently ignored.
//
// Usage:
//
// 1) Use the Mi_Prep.xls file to enter the Menu Item Names and Prices in Excel.
//
// 2) Export data from Excel into the Mi_Prep.csv file.
//
// 3) Copy Mi_Prep.csv into the "Mi_Import" directory.
//
// 4) Start Micros 3700 into the "Database" state.
//
// 5) Make sure in the "POS Configurator", that there is enough space after the last Menu Item
//    to accomodate the new items.
//
// 6) Colose the "POS Configurator".
//
// 7) Run Mi_Import.bat script to append the new Menu Items.
//
// 8) Use the "POS Configurator" to finish configuration of the new Menu Items.
//
// You can try Mi_Import.xls and Mi_Import.csv files from the "Samples" subdirectory.
//
//-------------------------------------------------------------------------------------
//	Designed by Boris Vasiliev	Version 1.00		January 24 2006
//
//	This script was tested with Micros 3700 V3.2 SP6 HF3
//
//-------------------------------------------------------------------------------------

CONNECT custom IDENTIFIED BY custom;


DECLARE LOCAL TEMPORARY TABLE "n"
	(
	mi_seq		NUMERIC (6),
	obj_num		NUMERIC (6),
	mi_price_seq	NUMERIC (6)
	)
	ON COMMIT PRESERVE ROWS;
//-------------------------------------------------------------------------------------
DECLARE LOCAL TEMPORARY TABLE "menu_items"
	(
	i 		NUMERIC (6) DEFAULT AUTOINCREMENT PRIMARY  KEY,	// Auto index the input data
	mi_seq		NUMERIC (6),
	mi_seq_m	NUMERIC (6),
	obj_num		NUMERIC (6),
	obj_num_m	NUMERIC (6),
	mi_price_seq	NUMERIC (6),
	mi_price_seq_m	NUMERIC (6),
	name_1		CHAR(16),
	name_2		CHAR(12),
	SLU		CHAR(16),
	Mi_Slu_Seq	NUMERIC(8),
	Price_1		MONEY12,					// preset_amt_1, etc
	Price_2		MONEY12,
	Price_3		MONEY12,
	Price_4		MONEY12,
	Price_5		MONEY12,
	Price_6		MONEY12,
	Price_7		MONEY12,
	Price_8		MONEY12,
	Price_9		MONEY12,
	Price_10	MONEY12
	)
	ON COMMIT PRESERVE ROWS;
//-------------------------------------------------------------------------------------
//-------------------------------------------------------------------------------------
IF
	(SELECT	MAX("mi_seq")			// Are there any Menu Items?
		FROM "micros"."mi_def") > 0
	THEN

	INSERT	INTO	"n"	("mi_seq", "obj_num")
		VALUES
			(
			(
			SELECT	MAX("mi_seq")
				FROM "micros"."mi_def"
			),
			(
			SELECT	MAX("obj_num")
				FROM "micros"."mi_def"
			)
			)
	ELSE
	INSERT	INTO	"n"	("mi_seq", "obj_num")
		VALUES	(0,0)
END IF;
//-------------------------------------------------------------------------------------
//	Import menu_items
//-------------------------------------------------------------------------------------
INPUT	INTO "menu_items"		// Load the CSV file
	FROM '.\mi_import.tmp'
	FORMAT ascii
		(
		"obj_num",
		"name_1",
		"name_2",
		"SLU",
		"Mi_Slu_Seq",
		"Price_1",
		"Price_2",
		"Price_3",
		"Price_4",
		"Price_5",
		"Price_6",
		"Price_7",
		"Price_8",
		"Price_9",
		"Price_10"
		);
//-------------------------------------------------------------------------------------
UPDATE	"menu_items"
	SET	"mi_seq_m"=	(
				SELECT MAX ("mi_seq")	FROM "n"
				);
//		"obj_num_m"=	(
//				SELECT MAX ("obj_num")	FROM "n"
//				);
//-------------------------------------------------------------------------------------
UPDATE	"menu_items"			// Set "mi_seq" and "obj_num" for the imported records
	SET	
		"mi_seq"="i"+"mi_seq_m";			
//		"obj_num"="i"+"obj_num_m";			
//-------------------------------------------------------------------------------------
INSERT	INTO	"micros"."mi_def"	// Import new records into the "mi_def"
		(
		"mi_seq",
		"obj_num",
		"name_1",
		"name_2"
		)
	SELECT
		"mi_seq",
		"obj_num",
		"name_1",
		"name_2"
		
	FROM	"menu_items"
	WHERE   "obj_num" IS NOT NULL;
//-------------------------------------------------------------------------------------
UPDATE	"menu_items" AS "mi1",		// Synchronize "mi_price_seq"
	"micros"."mi_price_def" AS "mdf1"
	SET	"mi1"."mi_price_seq"=
		(
		SELECT	MAX	( "mdf2"."mi_price_seq" )
			FROM	"menu_items" AS "mi2"
			INNER JOIN
			"micros"."mi_price_def" "mdf2"
			ON	("mi2"."mi_seq"="mdf2"."mi_seq")
			WHERE	"mi2"."mi_seq"="mdf2"."mi_seq"	AND
				"mi2"."mi_seq"="mi1"."mi_seq"
		)
	WHERE	"mi1"."mi_seq"="mdf1"."mi_seq";
//-------------------------------------------------------------------------------------
COMMIT;
//-------------------------------------------------------------------------------------
DELETE FROM	"menu_items"		// Remove empty entries
	WHERE
		"mi_price_seq" IS NULL OR
		(
		"name_1" IS NULL
		AND
		"name_2" IS NULL
		)			OR
		(
		"Price_1" IS NULL	AND
		"Price_2" IS NULL	AND
		"Price_3" IS NULL	AND
		"Price_4" IS NULL	AND
		"Price_5" IS NULL	AND
		"Price_6" IS NULL	AND
		"Price_7" IS NULL	AND
		"Price_8" IS NULL	AND
		"Price_9" IS NULL	AND
		"Price_10" IS NULL
		);

//-------------------------------------------------------------------------------------
COMMIT;
//-------------------------------------------------------------------------------------
//SELECT * FROM "menu_items"
//	># .\Mi_Import\Menu_Items.txt
//;
//-------------------------------------------------------------------------------------
					// Import prices
UPDATE	"micros"."mi_price_def"	AS "mpd"
	SET	
		"effective_from"='1996-01-01',
		"mpd"."preset_amt_1"="mi"."Price_1",
		"mpd"."preset_amt_2"="mi"."Price_2",
		"mpd"."preset_amt_3"="mi"."Price_3",
		"mpd"."preset_amt_4"="mi"."Price_4",
		"mpd"."preset_amt_5"="mi"."Price_5",
		"mpd"."preset_amt_6"="mi"."Price_6",
		"mpd"."preset_amt_7"="mi"."Price_7",
		"mpd"."preset_amt_8"="mi"."Price_8",
		"mpd"."preset_amt_9"="mi"."Price_9",
		"mpd"."preset_amt_10"="mi"."Price_10"
				
	FROM	"menu_items" AS "mi"
	WHERE	"mi"."mi_price_seq"="mpd"."mi_price_seq"	AND
		"mi"."mi_price_seq" IS NOT NULL
	ORDER	BY "mpd"."mi_price_seq", "mi"."mi_price_seq"
;
//-------------------------------------------------------------------------------------
//SELECT *	FROM	"menu_items";

SELECT * FROM "micros"."mi_price_def"
ORDER BY mi_price_seq DESC;
//-------------------------------------------------------------------------------------
COMMIT;
DELETE		FROM	"menu_items";
//
COMMIT;
//-------------------------------------------------------------------------------------
